@@ -191,6 +191,10 @@ def pytest_runtest_makereport(item, call):
         module_name_list.append(module_dict['story'])
     if module_dict['feature']:
         module_name_list.append(module_dict['feature'])
+
+    from pytestFlexReport.module_define_init_ import ModuleDefineInit
+    module_name_list.extend(ModuleDefineInit().get_testcase_module_list(item.fspath.dirname))
+    print(module_name_list)
     report.moduleName = '/'.join(module_name_list) if len(module_name_list) > 1 else item.location[0]
 
     if hasattr(item, 'callspec'):
